Package: mlr3misc
Title: Helper Functions for 'mlr3'
Version: 0.22.0
Authors@R: c(
    person("Marc", "Becker", , "marcbecker@posteo.de", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0002-8115-0400")),
    person("Michel", "Lang", , "michellang@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0001-9754-0393")),
    person("Patrick", "Schratz", , "patrick.schratz@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0003-0748-6624"))
  )
Description: Frequently used helper functions and assertions used in
    'mlr3' and its companion packages. Comes with helper functions for
    functional programming, for printing, to work with 'data.table', as
    well as some generally useful 'R6' classes. This package also
    supersedes the package 'BBmisc'.
License: LGPL-3
URL: https://mlr3misc.mlr-org.com, https://github.com/mlr-org/mlr3misc
BugReports: https://github.com/mlr-org/mlr3misc/issues
Depends: R (>= 3.4.0)
Imports: backports (>= 0.1.5), checkmate, cli, data.table, digest,
        methods, R6
Suggests: callr, evaluate, mirai, paradox, testthat (>= 3.0.0)
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
NeedsCompilation: yes
Collate: 'Dictionary.R' 'named_list.R' 'Callback.R' 'Context.R'
        'as_factor.R' 'as_short_string.R' 'assert_ro_binding.R'
        'calculate_hash.R' 'capitalize.R' 'cat_cli.R' 'catn.R'
        'check_operators.R' 'check_packages_installed.R' 'chunk.R'
        'compose.R' 'compute_mode.R' 'conditions.R' 'count_missing.R'
        'crate.R' 'cross_join.R' 'dictionary_sugar.R' 'did_you_mean.R'
        'distinct_values.R' 'encapsulate.R' 'enframe.R'
        'extract_vars.R' 'format_bib.R' 'formulate.R' 'get_private.R'
        'get_seed.R' 'has_element.R' 'ids.R' 'insert_named.R'
        'invoke.R' 'is_scalar_na.R' 'keep_in_bounds.R' 'leanify.R'
        'load_dataset.R' 'map_values.R' 'modify.R' 'named_vector.R'
        'names2.R' 'nin.R' 'open_help.R' 'printf.R' 'probe.R'
        'purrr_map.R' 'rcbind.R' 'rd_info.R' 'recycle_vector.R'
        'register_namespace_callback.R' 'remove_named.R'
        'reorder_vector.R' 'require_namespaces.R' 'rowwise_table.R'
        'seq.R' 'set_class.R' 'set_names.R' 'set_params.R' 'shuffle.R'
        'str_collapse.R' 'str_indent.R' 'str_trunc.R' 'strip_srcrefs.R'
        'to_decimal.R' 'topo_sort.R' 'transpose.R' 'unnest.R'
        'warn_deprecated.R' 'which_max.R' 'with_package.R' 'zzz.R'
Config/roxygen2/version: 8.0.0
Packaged: 2026-06-09 18:30:07 UTC; marc
Author: Marc Becker [cre, aut] (ORCID: <https://orcid.org/0000-0002-8115-0400>),
  Michel Lang [aut] (ORCID: <https://orcid.org/0000-0001-9754-0393>),
  Patrick Schratz [aut] (ORCID: <https://orcid.org/0000-0003-0748-6624>)
Maintainer: Marc Becker <marcbecker@posteo.de>
Repository: CRAN
Date/Publication: 2026-06-10 05:20:47 UTC
