# mlr3misc

Package website: [release](https://mlr3misc.mlr-org.com/) | [dev](https://mlr3misc.mlr-org.com/dev/)

Miscellaneous helper functions for [mlr3](https://mlr3.mlr-org.com).

<!-- badges: start -->
[![r-cmd-check](https://github.com/mlr-org/mlr3misc/actions/workflows/r-cmd-check.yml/badge.svg)](https://github.com/mlr-org/mlr3misc/actions/workflows/r-cmd-check.yml)
[![CRAN Status](https://www.r-pkg.org/badges/version-ago/mlr3misc)](https://cran.r-project.org/package=mlr3misc)
[![Mattermost](https://img.shields.io/badge/chat-mattermost-orange.svg)](https://lmmisld-lmu-stats-slds.srv.mwn.de/mlr_invite/)
<!-- badges: end -->

## Installation

Install the last release from CRAN:

``` r
install.packages("mlr3misc")
```

Install the development version from GitHub:

``` r
pak::pak("mlr-org/mlr3misc")
```
