% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nin.R
\name{\%nin\%}
\alias{\%nin\%}
\title{Negated in-operator}
\usage{
x \%nin\% y
}
\arguments{
\item{x}{(\code{vector()})\cr
Values that should not be in \code{y}.}

\item{y}{(\code{vector()})\cr
Values to match against.}
}
\description{
This operator is equivalent to \code{!(x \%in\% y)}.
}
