% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Callback.R
\name{call_back}
\alias{call_back}
\title{Call Callbacks}
\usage{
call_back(stage, callbacks, context)
}
\description{
Call list of callbacks with context at specific stage.
}
\keyword{internal}
